@charset "UTF-8";

/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Takahashi-Method-based Presentation Tool in XUL.
 *
 * The Initial Developer of the Original Code is SHIMODA Hiroshi.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): SHIMODA Hiroshi <piro@p.club.ne.jp>
 *
 * ***** END LICENSE BLOCK ***** */

#canvas {
	background: black !important;
	color: white !important;
        /* font-weight: bold; */
	font-family:
                "Georgia"
                "DejaVu Serif Condensed"
                "Arial"
		"Bitstream Vera Sans"
		"Verdana"
		"Apple LiGothic"
		"Arial Black"
                "Bitstream Vera Sans"
		sans-serif !important;
}
#canvas * {
	cursor: pointer !important;
}
#canvas image {
	width: auto;
	height: auto;
}
.link-text {
	color: #99CCFF !important;
	text-decoration: none !important;
}
.link-text:hover {
	color: #CCEEFF !important;
/*        border-bottom: dotted 1px; */
}
.link-text:active {
	color: white !important;
}
.s {
        text-decoration: line-through;
}
.iu {
        text-decoration: underline;
        font-style: italic;
}
.ui {
/*      text-decoration: underline; */
        font-style: italic;
}
.u {
        text-decoration: underline;
}
.i {
        font-style: italic;
        font-family: "Times New Roman"
                     "Bitstream Vera Serif"
                     serif;
}
.c {
        font-family: "Anonymous"
		     "Lucida Console"
		     "Andale Mono"
                     "Bitstream Vera Sans Mono"
                     monospace;
}
.t {
        font-style: italic;
}
.tag {
        color: #33ff33;
}
.att {
        color: #9999cc;
}
.key {
        color: #00ffff;
}
.hid {
        color: #999999;
}
.hidt {
        color: #999999;
        font-style: italic;
}
.pre {
        font-family: "Anonymous"
		     "Lucida Console"
		     "Andale Mono"
                     "Bitstream Vera Sans Mono"
                     monospace;
        padding-bottom: 8px;
}
#canvas[rendering="true"] image {
	display: none;
}
#canvas[rendering="true"] *,
#canvas[rendering="true"] .text-link {
	color: white !important;
}


tabbox, tabpanels, tabpanel {
	margin: 0;
	padding: 0;
}




#canvas[eva="true"] {
	background: white !important;
	color: black !important;
	font-family:
                "Georgia"
                "DejaVu Serif Condensed"
		"Apple LiGothic"
		"Arial Black"
		serif !important;
}
#canvas[eva="true"] .link-text {
	color: red !important;
	text-decoration: none !important;
}
#canvas[eva="true"] .link-text:hover {
	color: pink !important;
}
#canvas[eva="true"] .link-text:active {
	color: orange !important;
}
#canvas[rendering="true"] *,
#canvas[rendering="true"] .text-link {
	color: black !important;
}




#canvasToolbar {
	position: relative;
}

